@@ -11,7 +11,7 @@ import inspect
 import shutil
 from jinja2 import Environment, FileSystemLoader
 import glob
-from src.unitgrade.framework import Report
+from unitgrade.framework import Report
 from unitgrade_private import docker_helpers
 from importlib.machinery import SourceFileLoader
 
@@ -197,7 +197,7 @@ if __name__ == "__main__":
     output_tar = deploy_assignment("hello4", INSTRUCTOR_BASE, INSTRUCTOR_GRADE_FILE, STUDENT_BASE, STUDENT_GRADE_FILE=STUDENT_GRADE_FILE)
 
 
-def format_autolab_json(data):
+def format_autolab_json(data, indent=None):
     import json
 
     stages = []
@@ -205,6 +205,7 @@ def format_autolab_json(data):
         "_presentation": "semantic",
         "stages": [], # "Build", "Test", "Timing"],
     }
+    totals = {}
     for n, qs in data['details'].items():
         print(n)
         title = qs['title']
@@ -213,11 +214,12 @@ def format_autolab_json(data):
             print(item, val)
             item_name = item[1]
             rs[item_name] = {'passed': val['status'] == 'pass'}
-        rs['Total'] = qs['obtained']
+        totals[title] = qs['obtained']
         stages.append(title)
         pres[title] = rs
+    stages.append("Total")
     pres['stages'] = stages
-
+    pres['Total'] = totals
     # rs = {
     #     "_presentation": "semantic",
     #     "stages": ["Build", "Test", "Timing"],
@@ -233,12 +235,13 @@ def format_autolab_json(data):
     #     'scores': 234,
     #       'pass': True
     # }
-    # s = json.dumps(pres, indent=2)
-    s = json.dumps(pres)
+    if indent is not None:
+        s = json.dumps(pres, indent=2)
+    else:
+        s = json.dumps(pres)
     print(s)
-    scores = {"scores": {"Total": data['total'][0], 'Possible': data['total'][1]}}
+    scores = {"scores": {"Total": data['total'][0] }}
     print( json.dumps(scores) )
 
-
     a = 234
     pass
\ No newline at end of file
